@@ -17,7 +17,7 @@ has missing_after => 1800;
 has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '8.05';
+our $VERSION = '8.06';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -633,6 +633,12 @@ These fields are currently available:
 
 Number of jobs in C<active> state.
 
+=item active_locks
+
+  active_locks => 100
+
+Number of active named locks.
+
 =item active_workers
 
   active_workers => 100
